summaryrefslogtreecommitdiffstats
path: root/src/Generating/Trees.h
diff options
context:
space:
mode:
authorHowaner <franzi.moos@googlemail.com>2014-02-19 19:18:40 +0100
committerHowaner <franzi.moos@googlemail.com>2014-02-19 19:18:40 +0100
commit16f3809ded538611c6c26a41316cf35bb8b1f5a5 (patch)
tree5479bee290c6d5c46a0db2e878a84bf962a22409 /src/Generating/Trees.h
parentAdd new Trees (without Generator) (diff)
downloadcuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar.gz
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar.bz2
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar.lz
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar.xz
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.tar.zst
cuberite-16f3809ded538611c6c26a41316cf35bb8b1f5a5.zip
Diffstat (limited to 'src/Generating/Trees.h')
-rw-r--r--src/Generating/Trees.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Generating/Trees.h b/src/Generating/Trees.h
index 7619f4458..00f343a3d 100644
--- a/src/Generating/Trees.h
+++ b/src/Generating/Trees.h
@@ -66,8 +66,8 @@ void GetBirchTreeImage(int a_BlockX, int a_BlockY, int a_BlockZ, cNoise & a_Nois
/// Generates an image of a random acacia tree
void GetAcaciaTreeImage(int a_BlockX, int a_BlockY, int a_BlockZ, cNoise & a_Noise, int a_Seq, sSetBlockVector & a_LogBlocks, sSetBlockVector & a_OtherBlocks);
-/// Generates an image of a random darkoac tree
-void GetDarkoacTreeImage(int a_BlockX, int a_BlockY, int a_BlockZ, cNoise & a_Noise, int a_Seq, sSetBlockVector & a_LogBlocks, sSetBlockVector & a_OtherBlocks);
+/// Generates an image of a random darkoak tree
+void GetDarkoakTreeImage(int a_BlockX, int a_BlockY, int a_BlockZ, cNoise & a_Noise, int a_Seq, sSetBlockVector & a_LogBlocks, sSetBlockVector & a_OtherBlocks);
/// Generates an image of a random large birch tree
void GetTallBirchTreeImage(int a_BlockX, int a_BlockY, int a_BlockZ, cNoise & a_Noise, int a_Seq, sSetBlockVector & a_LogBlocks,sSetBlockVector & a_OtherBlocks);